@@ -28,18 +28,20 @@ def migrate():
     doma_host = 'https://aipanda015.cern.ch:443/idds'   # noqa F841
     # atlas
     atlas_host = 'https://aipanda181.cern.ch:443/idds'  # noqa F841
+    # doma google
+    doma_google_host = 'https://34.133.138.229:443/idds'  # noqa F841
 
     cm1 = ClientManager(host=doma_host)
     # reqs = cm1.get_requests(request_id=290)
     # old_request_id = 298163
-    old_request_id = 965
+    old_request_id = 901
     # for old_request_id in [152]:
     # for old_request_id in [60]:    # noqa E115
     # for old_request_id in [200]:    # noqa E115
     for old_request_id in [old_request_id]:    # noqa E115  # doma 183
         reqs = cm1.get_requests(request_id=old_request_id, with_metadata=True)
 
-        cm2 = ClientManager(host=dev_host)
+        cm2 = ClientManager(host=doma_google_host)
         # print(reqs)
 
         print("num requests: %s" % len(reqs))
